package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.ZxFjMapper;
import com.ruoyi.system.domain.ZxFj;
import com.ruoyi.system.service.IZxFjService;

/**
 * 政协_附件Service业务层处理
 * 
 * @author boman
 * @date 2024-03-07
 */
@Service
public class ZxFjServiceImpl implements IZxFjService 
{
    @Autowired
    private ZxFjMapper zxFjMapper;

    /**
     * 查询政协_附件
     * 
     * @param id 政协_附件主键
     * @return 政协_附件
     */
    @Override
    public ZxFj selectZxFjById(Long id)
    {
        return zxFjMapper.selectZxFjById(id);
    }

    /**
     * 查询政协_附件列表
     * 
     * @param zxFj 政协_附件
     * @return 政协_附件
     */
    @Override
    public List<ZxFj> selectZxFjList(ZxFj zxFj)
    {
        return zxFjMapper.selectZxFjList(zxFj);
    }

    /**
     * 新增政协_附件
     * 
     * @param zxFj 政协_附件
     * @return 结果
     */
    @Override
    public int insertZxFj(ZxFj zxFj)
    {
        return zxFjMapper.insertZxFj(zxFj);
    }

    /**
     * 修改政协_附件
     * 
     * @param zxFj 政协_附件
     * @return 结果
     */
    @Override
    public int updateZxFj(ZxFj zxFj)
    {
        return zxFjMapper.updateZxFj(zxFj);
    }

    /**
     * 批量删除政协_附件
     * 
     * @param ids 需要删除的政协_附件主键
     * @return 结果
     */
    @Override
    public int deleteZxFjByIds(Long[] ids)
    {
        return zxFjMapper.deleteZxFjByIds(ids);
    }

    /**
     * 删除政协_附件信息
     * 
     * @param id 政协_附件主键
     * @return 结果
     */
    @Override
    public int deleteZxFjById(Long id)
    {
        return zxFjMapper.deleteZxFjById(id);
    }
}
